[pango] Remove remaining uses of g_utf8_strlen()



commit d0d140b0180bfe2c2278f34f5a649a2e7d9f4fa2
Author: Behdad Esfahbod <behdad behdad org>
Date:   Fri Aug 21 13:53:34 2015 +0100

    Remove remaining uses of g_utf8_strlen()

 pango/break-thai.c          |    7 ++++---
 pango/pangocoretext-shape.c |    2 +-
 pango/pangowin32-shape.c    |    3 ++-
 3 files changed, 7 insertions(+), 5 deletions(-)
---
diff --git a/pango/pangocoretext-shape.c b/pango/pangocoretext-shape.c
index ef066ee..60f6b16 100644
--- a/pango/pangocoretext-shape.c
+++ b/pango/pangocoretext-shape.c
@@ -401,7 +401,7 @@ _pango_core_text_shape (PangoFont           *font,
     return;
 
   /* Translate the glyph list to a PangoGlyphString */
-  n_chars = g_utf8_strlen (text, length);
+  n_chars = pango_utf8_strlen (text, length);
   pango_glyph_string_set_size (glyphs, n_chars);
 
   glyph_iter = glyph_list;
diff --git a/pango/pangowin32-shape.c b/pango/pangowin32-shape.c
index aa69d2c..fbd0012 100644
--- a/pango/pangowin32-shape.c
+++ b/pango/pangowin32-shape.c
@@ -34,6 +34,7 @@
 extern HFONT _pango_win32_font_get_hfont (PangoFont *font);
 
 #include "pango-utils.h"
+#include "pango-impl-utils.h"
 
 static gboolean pango_win32_debug = FALSE;
 
@@ -673,7 +674,7 @@ _pango_win32_shape (PangoFont               *font,
       uniscribe_shape (font, text, length, analysis, glyphs))
     return;
 
-  n_chars = g_utf8_strlen (text, length);
+  n_chars = pango_utf8_strlen (text, length);
 
   pango_glyph_string_set_size (glyphs, n_chars);
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/pango/break-thai.c b/pango/break-thai.c
index 4a2d7d7..659e96e 100644
--- a/pango/break-thai.c
+++ b/pango/break-thai.c
@@ -20,7 +20,8 @@
 
 #include "config.h"
 
-#include <pango/pango-break.h>
+#include "pango-break.h"
+#include "pango-impl-utils.h"
 
 #ifdef HAVE_LIBTHAI
 #include <thai/thwchar.h>
@@ -30,7 +31,7 @@ G_LOCK_DEFINE_STATIC (th_brk);
 
 /*
  * tis_text is assumed to be large enough to hold the converted string,
  * i.e. it must be at least g_utf8_strlen(text, len)+1 bytes.
  */
 static thchar_t *
 utf8_to_tis (const char *text, int len, thchar_t *tis_text, int *tis_cnt)
@@ -62,7 +63,7 @@ break_thai (const char          *text,
   int *brk_pnts;
   int cnt;
 
-  cnt = g_utf8_strlen (text, len) + 1;
+  cnt = pango_utf8_strlen (text, len) + 1;
 
   tis_text = tis_stack;
   if (cnt > (int) G_N_ELEMENTS (tis_stack))
@@ -30,7 +31,7 @@ G_LOCK_DEFINE_STATIC (th_brk);
 /*
  * tis_text is assumed to be large enough to hold the converted string,
- * i.e. it must be at least g_utf8_strlen(text, len)+1 bytes.
+ * i.e. it must be at least pango_utf8_strlen(text, len)+1 bytes.
  */
 static thchar_t *